#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

""" A list of common keybindings and unbound keys
    pulled out from default.py: __getLaptopBindings()
    with the goal of being more readable and less monolithic.
"""

__id__ = "$Id$"
__version__   = "$Revision$"
__date__      = "$Date$"
__copyright__ = "Copyright (c) 2010 Joanmarie Diggs, Mesar Hameed."
__license__   = "LGPL"

from . import keybindings

# Storing values 
defaultModifierMask = keybindings.defaultModifierMask
CTHULHU_MODIFIER_MASK = keybindings.CTHULHU_MODIFIER_MASK
NO_MODIFIER_MASK = keybindings.NO_MODIFIER_MASK
CTHULHU_SHIFT_MODIFIER_MASK = keybindings.CTHULHU_SHIFT_MODIFIER_MASK
CTHULHU_CTRL_MODIFIER_MASK = keybindings.CTHULHU_CTRL_MODIFIER_MASK

keymap = (

    ("9", defaultModifierMask, CTHULHU_MODIFIER_MASK,
    "routePointerToItemHandler"),

    # We want the user to be able to combine modifiers with the
    # mouse click (e.g. to Shift+Click and select), therefore we
    # do not "care" about the modifiers (other than the Cthulhu
    # modifier).
    #

    ("7", CTHULHU_MODIFIER_MASK, CTHULHU_MODIFIER_MASK,
    "leftClickReviewItemHandler"),

    ("8", CTHULHU_MODIFIER_MASK, CTHULHU_MODIFIER_MASK,
    "rightClickReviewItemHandler"),

    ("semicolon", defaultModifierMask, CTHULHU_MODIFIER_MASK,
    "sayAllHandler", 1),

    ("bracketleft", defaultModifierMask, CTHULHU_MODIFIER_MASK,
    "findHandler"),

    ("bracketright", defaultModifierMask, CTHULHU_MODIFIER_MASK,
    "findNextHandler"),

    ("bracketright", defaultModifierMask, CTHULHU_CTRL_MODIFIER_MASK,
    "findPreviousHandler"),

)
