#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of find result presentation."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("<Control>Home"))
sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("<Control>F"))
sequence.append(PauseAction(3000))
sequence.append(TypeAction("cthulhu"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Return"))
sequence.append(utils.AssertPresentationAction(
    "1. Return to next result",
    ["BRAILLE LINE:  'Welcome to Cthulhu! h1'",
     "     VISIBLE:  'Welcome to Cthulhu! h1', cursor=16",
     "SPEECH OUTPUT: 'Welcome to Cthulhu! heading level 1'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Return"))
sequence.append(utils.AssertPresentationAction(
    "2. Return to next result",
    ["BRAILLE LINE:  'Welcome to Cthulhu!'",
     "     VISIBLE:  'Welcome to Cthulhu!', cursor=1",
     "SPEECH OUTPUT: '1.'",
     "SPEECH OUTPUT: 'Welcome to Cthulhu!'",
     "SPEECH OUTPUT: 'link.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Return"))
sequence.append(utils.AssertPresentationAction(
    "3. Return to next result",
    ["BRAILLE LINE:  'Cthulhu is a free, open source, flexible, extensible, and '",
     "     VISIBLE:  'Cthulhu is a free, open source, fle', cursor=5",
     "SPEECH OUTPUT: 'Cthulhu is a free, open source, flexible, extensible, and'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Return"))
sequence.append(utils.AssertPresentationAction(
    "4. Return to next result",
    ["BRAILLE LINE:  'synthesis, braille, and magnification, Cthulhu helps provide '",
     "     VISIBLE:  'magnification, Cthulhu helps provid', cursor=20",
     "SPEECH OUTPUT: 'synthesis, braille, and magnification, Cthulhu helps provide'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Escape"))
sequence.append(utils.AssertPresentationAction(
    "5. Escape to return to page content",
    ["BRAILLE LINE:  'synthesis, braille, and magnification, Cthulhu helps provide '",
     "     VISIBLE:  'magnification, Cthulhu helps provid', cursor=20",
     "SPEECH OUTPUT: 'synthesis, braille, and magnification, Cthulhu helps provide  selected'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "6. Down arrow to be sure we've updated our position",
    ["BRAILLE LINE:  'access to applications and toolkits that support the AT-SPI'",
     "     VISIBLE:  'access to applications and toolk', cursor=1",
     "SPEECH OUTPUT: 'access to applications and toolkits that support the AT-SPI'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
