#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of table structural navigation with empty tables."""

from macaroon.playback import *
import utils

sequence = MacroSequence()

#sequence.append(WaitForDocLoad())
sequence.append(PauseAction(5000))
sequence.append(KeyComboAction("<Control>Home"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("t"))
sequence.append(utils.AssertPresentationAction(
    "1. t",
    ["BRAILLE LINE:  'table with 2 rows 3 columns'",
     "     VISIBLE:  'table with 2 rows 3 columns', cursor=0",
     "BRAILLE LINE:  'col 1'",
     "     VISIBLE:  'col 1', cursor=0",
     "SPEECH OUTPUT: 'table with 2 rows 3 columns' voice=system",
     "SPEECH OUTPUT: 'col 1'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("t"))
sequence.append(utils.AssertPresentationAction(
    "2. t",
    ["BRAILLE LINE:  'table with 2 rows 3 columns'",
     "     VISIBLE:  'table with 2 rows 3 columns', cursor=0",
     "BRAILLE LINE:  '1'",
     "     VISIBLE:  '1', cursor=0",
     "SPEECH OUTPUT: 'table with 2 rows 3 columns' voice=system",
     "SPEECH OUTPUT: '1.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("t"))
sequence.append(utils.AssertPresentationAction(
    "3. t",
    ["BRAILLE LINE:  'Wrapping to top.'",
     "     VISIBLE:  'Wrapping to top.', cursor=0",
     "BRAILLE LINE:  'table with 2 rows 3 columns'",
     "     VISIBLE:  'table with 2 rows 3 columns', cursor=0",
     "BRAILLE LINE:  'col 1'",
     "     VISIBLE:  'col 1', cursor=0",
     "SPEECH OUTPUT: 'Wrapping to top.' voice=system",
     "SPEECH OUTPUT: 'table with 2 rows 3 columns' voice=system",
     "SPEECH OUTPUT: 'col 1'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>t"))
sequence.append(utils.AssertPresentationAction(
    "4. shift+t", 
    ["BRAILLE LINE:  'Wrapping to bottom.'",
     "     VISIBLE:  'Wrapping to bottom.', cursor=0",
     "BRAILLE LINE:  'table with 2 rows 3 columns'",
     "     VISIBLE:  'table with 2 rows 3 columns', cursor=0",
     "BRAILLE LINE:  '1'",
     "     VISIBLE:  '1', cursor=0",
     "SPEECH OUTPUT: 'Wrapping to bottom.' voice=system",
     "SPEECH OUTPUT: 'table with 2 rows 3 columns' voice=system",
     "SPEECH OUTPUT: '1.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>t"))
sequence.append(utils.AssertPresentationAction(
    "5. shift+t", 
    ["BRAILLE LINE:  'table with 2 rows 3 columns'",
     "     VISIBLE:  'table with 2 rows 3 columns', cursor=0",
     "BRAILLE LINE:  'col 1'",
     "     VISIBLE:  'col 1', cursor=0",
     "SPEECH OUTPUT: 'table with 2 rows 3 columns' voice=system",
     "SPEECH OUTPUT: 'col 1 column header'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>t"))
sequence.append(utils.AssertPresentationAction(
    "6. shift+t",
    ["BRAILLE LINE:  'Wrapping to bottom.'",
     "     VISIBLE:  'Wrapping to bottom.', cursor=0",
     "BRAILLE LINE:  'table with 2 rows 3 columns'",
     "     VISIBLE:  'table with 2 rows 3 columns', cursor=0",
     "BRAILLE LINE:  '1'",
     "     VISIBLE:  '1', cursor=0",
     "SPEECH OUTPUT: 'Wrapping to bottom.'",
     "SPEECH OUTPUT: 'table with 2 rows 3 columns'",
     "SPEECH OUTPUT: '1.'"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
